==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/CollectionActiveItemContext.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/CollectionActiveItemContext", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../config/constants/itemTypes', '../config/constants/layoutDataItemTypes', '../store/index', './CollectionItemContext', './Controls'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.CollectionActiveItemContextProvider = CollectionActiveItemContextProvider;
    exports.useSetCollectionActiveItemContext = useSetCollectionActiveItemContext;
    exports.useCollectionActiveItemContext = useCollectionActiveItemContext;

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _itemTypes = require("../config/constants/itemTypes");

    var _layoutDataItemTypes = require("../config/constants/layoutDataItemTypes");

    var _index = require("../store/index");

    var _CollectionItemContext = require("./CollectionItemContext");

    var _Controls = require("./Controls");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var CollectionActiveItemDispatchContext = _react["default"].createContext(function () {});

    var CollectionActiveItemStateContext = _react["default"].createContext(_CollectionItemContext.INITIAL_STATE);

    function CollectionActiveItemContextProvider(_ref) {
      var children = _ref.children;

      var _useState = (0, _react.useState)(_CollectionItemContext.INITIAL_STATE),
          _useState2 = _slicedToArray(_useState, 2),
          state = _useState2[0],
          setState = _useState2[1];

      return _react["default"].createElement(CollectionActiveItemDispatchContext.Provider, {
        value: setState
      }, _react["default"].createElement(CollectionActiveItemStateContext.Provider, {
        value: state
      }, children));
    }

    function useSetCollectionActiveItemContext(itemId) {
      var activeItemId = (0, _Controls.useActiveItemId)();
      var activeItemType = (0, _Controls.useActiveItemType)();
      var isActive = (0, _Controls.useIsActive)();
      var collectionContext = (0, _react.useContext)(_CollectionItemContext.CollectionItemContext);
      var setState = (0, _react.useContext)(CollectionActiveItemDispatchContext);
      var item = (0, _index.useSelectorCallback)(function (state) {
        return state.layoutData.items[itemId];
      }, [itemId]);

      if (isActive(itemId) || item && item.type === _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.fragment && activeItemType === _itemTypes.ITEM_TYPES.editable && activeItemId && activeItemId.startsWith(item.config.fragmentEntryLinkId)) {
        setState(collectionContext);
      }
    }

    function useCollectionActiveItemContext() {
      return (0, _react.useContext)(CollectionActiveItemStateContext);
    }
    //# sourceMappingURL=CollectionActiveItemContext.js.map
  }
});
//# sourceMappingURL=CollectionActiveItemContext.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/CollectionActiveItemContext.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/CollectionActiveItemContext", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../config/constants/itemTypes', '../config/constants/layoutDataItemTypes', '../store/index', './CollectionItemContext', './Controls'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.CollectionActiveItemContextProvider = CollectionActiveItemContextProvider;
    exports.useSetCollectionActiveItemContext = useSetCollectionActiveItemContext;
    exports.useCollectionActiveItemContext = useCollectionActiveItemContext;

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _itemTypes = require("../config/constants/itemTypes");

    var _layoutDataItemTypes = require("../config/constants/layoutDataItemTypes");

    var _index = require("../store/index");

    var _CollectionItemContext = require("./CollectionItemContext");

    var _Controls = require("./Controls");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var CollectionActiveItemDispatchContext = /*#__PURE__*/_react.default.createContext(function () {});

    var CollectionActiveItemStateContext = /*#__PURE__*/_react.default.createContext(_CollectionItemContext.INITIAL_STATE);

    function CollectionActiveItemContextProvider(_ref) {
      var children = _ref.children;

      var _useState = (0, _react.useState)(_CollectionItemContext.INITIAL_STATE),
          _useState2 = _slicedToArray(_useState, 2),
          state = _useState2[0],
          setState = _useState2[1];

      return (/*#__PURE__*/_react.default.createElement(CollectionActiveItemDispatchContext.Provider, {
          value: setState
        }, /*#__PURE__*/_react.default.createElement(CollectionActiveItemStateContext.Provider, {
          value: state
        }, children))
      );
    }

    function useSetCollectionActiveItemContext(itemId) {
      var activeItemId = (0, _Controls.useActiveItemId)();
      var activeItemType = (0, _Controls.useActiveItemType)();
      var isActive = (0, _Controls.useIsActive)();
      var collectionContext = (0, _react.useContext)(_CollectionItemContext.CollectionItemContext);
      var setState = (0, _react.useContext)(CollectionActiveItemDispatchContext);
      var item = (0, _index.useSelectorCallback)(function (state) {
        return state.layoutData.items[itemId];
      }, [itemId]);

      if (isActive(itemId) || item && item.type === _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.fragment && activeItemType === _itemTypes.ITEM_TYPES.editable && activeItemId && activeItemId.startsWith(item.config.fragmentEntryLinkId)) {
        setState(collectionContext);
      }
    }

    function useCollectionActiveItemContext() {
      return (0, _react.useContext)(CollectionActiveItemStateContext);
    }
    //# sourceMappingURL=CollectionActiveItemContext.js.map
  }
});
//# sourceMappingURL=CollectionActiveItemContext.js.map
